// Claude Blanger - AS/400 Support Center 12-19-1997
/********************************************************************/
/* COPYRIGHTS:                                                      */
/*                                                                  */
/*   This module contains code made available by IBM Corporation on */
/* an AS IS basis.  Any one receiving the module is  considered  to */
/* be  licensed under IBM copyrights to use the IBM-provided source */
/* code in any way he or  she  deems  fit,  including  copying  it, */
/* compiling  it,  modifying  it,  and  redistributing  it, with or */
/* without modifications.  No license  under  any  IBM  patents  or */
/* patent  applications  is  to  be  implied  from  this  copyright */
/* license.                                                         */
/*                                                                  */
/*   A user of the module should understand that IBM cannot provide */
/* technical support for the module and will not be responsible for */
/* any consequences of use of the program.                          */
/*                                                                  */
/*   Any notice,  including this one, are not to  be  removed  from */
/* the module with out the prior written consent of IBM.            */
/*                                                                  */
/********************************************************************/
#include <iostream.h>

// Include API header files
#include "cwb.h"                   // Client Access API header file.
#include "cwbsy.h"                 // Security API header file.
#include "cwbsv.h"                 // Service/Error header file.


// Display help information on required parameters
void HelpScreen(void)
{
	cout << endl;
	cout << "************************************************" << endl;
	cout << "*  You need to give the following parameters   *" << endl;
	cout << "*    AS/400 User ID  Password  System Name     *" << endl;
	cout << "************************************************" << endl;
	cout << "*  Call the application this way:              *" << endl;
	cout << "*  LOGONUSR [USERID] [PASSWORD] [SYSTEM NAME]  *" << endl;
	cout << "************************************************" << endl;
}

// Declaration for the LogonUserErr function
unsigned int LogonUserErr(unsigned int rc);

	cwbSY_SecurityHandle secHandle; // Used to hold a handle to a security object.
	cwbSV_ErrHandle      errHandle; // Used to hold a handle to an error object.

int main(unsigned short argc, char * argp[])
{
	// First we must setup the required data items.
	unsigned int rc;                // Used to hold the return code.
	char userId[11] = "",			// Used to hold the user id
	    userPws[11] = "",			// Used to hold the password
		sysName[30] = "";			// Used to hold the system name

	// We need to look to make sure that we have the right amount of parameters
    if (argc!=4)
    {
		HelpScreen();
		return 0;
    }

	// We need to copy the parameters to the appropriate variables
    strcpy(userId, argp[1]);
    strcpy(userPws, argp[2]);
    strcpy(sysName, argp[3]);

	// To access any error messages that are generated, you need to create
	// an error object:
	rc = cwbSV_CreateErrHandle(&errHandle);
	if (rc != 0 ) return rc;

	// To use the security APIs you'll first need to create a security
	// object to work with.
	rc = cwbSY_CreateSecurityObj(&secHandle);
	if (rc != 0 ) return LogonUserErr(rc);

	// Now you have a security object.  So, next you need to set the name
	// of the system.
	rc = cwbSY_SetSys(secHandle, sysName);
	if (rc != 0 ) return LogonUserErr(rc);

	// After the system name is setup you can then make the call to the 
	// cwbSY_LogonUser
	rc = cwbSY_LogonUser(secHandle,          // Security handle
	                     userId,             // User ID
						 userPws,            // Password
						 errHandle);         // Error Handle
	if (rc != 0 ) return LogonUserErr(rc);

	// Now we must perform some clean up work so we will delete the
	// security object when you are finished.
	cwbSY_DeleteSecurityObj(secHandle);
	cwbSV_DeleteErrHandle(errHandle);

	return 0;
}

unsigned int LogonUserErr(unsigned int rc)
{
	char szErrText[256];
	//query error object here
	cwbSV_GetErrText(errHandle,
				szErrText,
				(long) sizeof(szErrText),
				NULL);
	if (strlen(szErrText) > 1)
		cout << szErrText;
	else
		cout << "Error rc " << rc << ".  No associated error message";
	cwbSY_DeleteSecurityObj(secHandle);
	cwbSV_DeleteErrHandle(errHandle);
	return rc;
}